# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: federated.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'federated.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x66\x65\x64\x65rated.proto\"0\n\x0cModelRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0f\n\x07weights\x18\x02 \x03(\x0c\"1\n\x0eServerResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x1d\n\nKeyRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\"!\n\x0bKeyResponse\x12\x12\n\npublic_key\x18\x01 \x01(\t2n\n\x10\x46\x65\x64\x65ratedService\x12+\n\tSendModel\x12\r.ModelRequest\x1a\x0f.ServerResponse\x12-\n\x10RequestPublicKey\x12\x0b.KeyRequest\x1a\x0c.KeyResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'federated_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODELREQUEST']._serialized_start=19
  _globals['_MODELREQUEST']._serialized_end=67
  _globals['_SERVERRESPONSE']._serialized_start=69
  _globals['_SERVERRESPONSE']._serialized_end=118
  _globals['_KEYREQUEST']._serialized_start=120
  _globals['_KEYREQUEST']._serialized_end=149
  _globals['_KEYRESPONSE']._serialized_start=151
  _globals['_KEYRESPONSE']._serialized_end=184
  _globals['_FEDERATEDSERVICE']._serialized_start=186
  _globals['_FEDERATEDSERVICE']._serialized_end=296
# @@protoc_insertion_point(module_scope)
